- stid
a character vector of four-digit station identifiers
for the Mesonet stations from which to download data
- start_date
the first date for which to download data specified in
Central Standard Time (i.e. "America/Costa_Rica") zone as a Date or POSIXt
object or a string with the format YYYY-MM-DD, where YYYY is the four-digit
year, MM is the two-digit numeric month and DD is the two-digit day of month
- end_date
the final date for which to download data specified in
Central Standard Time (i.e. "America/Costa_Rica") zone as a Date or POSIXt
object or a string with the format YYYY-MM-DD, where YYYY is the four-digit
year, MM is the two-digit numeric month and DD is the two-digit day of month
- root_url
the root url from which to download MTS files (see
mnet_root_url)
- site_info
a data frame with site and soil information for each
Oklahoma Mesonet station as returned by mnet_site_info. If
NULL, mnet_site_info will be used to download this
information internally
- file_cache
a character string providing a path to the local Mesonet
file cache. If NULL, the function will search for the local file cache and
if not found will prompt the user to create one.
- ask
whether or not to ask about creating a local Mesonet file cache
- silent
whether to suppress output to terminal (TRUE) or allow output
to terminal (FALSE)