Learn R Programming

mesonet (version 0.0.2)

mnet_van_genuchten: Calculate volumetric soil water content with van Genuchten curve

Description

Calculate volumetric soil water content using the van Genuchten curve

Usage

mnet_van_genuchten(MP, WCr, WCs, a, n)

Value

a vector of volumetric soil water content values

Arguments

MP

a vector of matric potential at which to calculate volumetric soil water content

WCr

residual water content for dry soil

WCs

saturated water content for wet soil

a

the alpha parameter for the van Genuchten equation related to the inverse of the air entry suction

n

the n parameter for the van Genuchten equation related to the pore-size distribution

Examples

Run this code

mnet_van_genuchten(-100, 0.034, 0.41, 0.273, 1.39)

Run the code above in your browser using DataLab