mnet_calc_mp: Calculate soil matric potential for Oklahoma Mesonet data
Description
Calculate soil matric potential from delta-T soil temperature change data
from the Oklahoma Mesonet using the equation from Zhang et al (2019) <doi:10.2136/sssaj2018.12.0481>: MP = 2083/(1+ exp(-3.35*(Tref-3.17)))
where Tref is the measured delta-T data
Usage
mnet_calc_mp(data)
Value
a data frame containing new columns with matric potential (kPa) for each
column of delta-T temperature change data.
Arguments
data
a data frame that contains columns for delta-T temperature change
data (i.e. TR05, TR25, TR60, TR75)